@@ -38,6 +38,8 @@ class Filter:
         The line color used when plotting photometry in this filter. Default: same as ``color``.
     textcolor : str, tuple, optional
         The color used when printing the name of this filter. Default: same as ``linecolor``.
+    italics : bool, optional
+        Italicize the filter name when used with LaTeX. Default: True.
 
     Attributes
     ----------
@@ -53,6 +55,8 @@ class Filter:
         The line color used when plotting photometry in this filter
     textcolor : str, tuple
         The color used when printing the name of this filter
+    italics : bool
+        Italicize the filter name when used with LaTeX
     mec : str, tuple
         The marker edge color used when plotting photometry in this filter
     plotstyle : dict
@@ -86,7 +90,7 @@ class Filter:
     """The names of recognized filters listed in (approximate) decreasing order of effective frequency"""
 
     def __init__(self, names, color='k', offset=0, system=None, fnu=3.631e-23, filename='', angstrom=False,
-                 linecolor=None, textcolor=None):
+                 linecolor=None, textcolor=None, italics=True):
         if type(names) == list:
             self.name = names[0]
             self.names = names
@@ -110,6 +114,7 @@ class Filter:
             self.textcolor = textcolor
         else:
             self.textcolor = self.linecolor
+        self.italics = italics
         self.system = system
         if self.system == 'Johnson':
             self.mec = 'k'
@@ -191,6 +196,9 @@ class Filter:
                 ax2.set_xlabel('Frequency (THz)')
                 ax2.set_ylabel('Transmission')
 
+            self.wl_eff = wl_eff
+            self.dwl = dwl
+            self.wl_range = (wl_eff.value - wl0, wl1 - wl_eff.value)
             self.freq_eff = freq_eff
             self.dfreq = -dfreq
             self.freq_range = (freq_eff.value - freq0, freq1 - freq_eff.value)
@@ -252,39 +260,42 @@ all_filters = [
     Filter(['UVW2', 'uvw2', 'W2', '2', 'uw2'], '#FF007F', 8, 'Swift', 7.379e-24, 'Swift_UVOT.UVW2.dat', angstrom=True),
     Filter(['UVM2', 'uvm2', 'M2', 'M', 'um2'], 'm', 8, 'Swift', 7.656e-24, 'Swift_UVOT.UVM2.dat', angstrom=True),
     Filter(['UVW1', 'uvw1', 'W1', '1', 'uw1'], '#7F00FF', 4, 'Swift', 9.036e-24, 'Swift_UVOT.UVW1.dat', angstrom=True),
-    Filter(['u', "u'", 'up'], '#4700CC', 3, 'Gunn', filename='sdss-up-183.asci'),  # brightened from '#080017'
+    Filter(['u', "u'", 'up'], '#4700CC', 3, 'Gunn', filename='SLOAN_SDSS.u.dat', angstrom=True),  # brightened from '#080017'
     Filter(['U_S', 's', 'us'], '#230047', 3, 'Swift', 1.419e-23, filename='Swift_UVOT.U.dat', angstrom=True),
-    Filter('U', '#3C0072', 3, 'Johnson', 1.790e-23, filename='jnsn-uv-183.asci'),
-    Filter('B', '#0057FF', 2, 'Johnson', 4.063e-23, filename='jnsn-bu-183.asci'),
+    Filter('U', '#3C0072', 3, 'Johnson', 1.790e-23, filename='Generic_Johnson.U.dat', angstrom=True),
+    Filter('B', '#0057FF', 2, 'Johnson', 4.063e-23, filename='Generic_Johnson.B.dat', angstrom=True),
     Filter(['B_S', 'b', 'bs'], '#4B00FF', 2, 'Swift', 4.093e-23, filename='Swift_UVOT.B.dat', angstrom=True),
-    Filter(['g', "g'", 'gp', 'F475W'], '#00CCFF', 1, 'Gunn', filename='sdss-gp-183.asci'),
+    Filter(['g', "g'", 'gp', 'F475W'], '#00CCFF', 1, 'Gunn', filename='SLOAN_SDSS.g.dat', angstrom=True),
     Filter('g-DECam', '#00CCFF', 1, 'DECam', filename='CTIO_DECam.g.dat', angstrom=True),
     Filter(['c', 'cyan'], 'c', 1, 'ATLAS', filename='ATLAS_cyan.txt'),
-    Filter('V', '#79FF00', 1, 'Johnson', 3.636e-23, filename='jnsn-vx-183.asci', textcolor='#46CC00'),
+    Filter('V', '#79FF00', 1, 'Johnson', 3.636e-23, filename='Generic_Johnson.V.dat', angstrom=True, textcolor='#46CC00'),
     Filter(['V_S', 'v', 'vs'], '#00FF30', 1, 'Swift', 3.664e-23, filename='Swift_UVOT.V.dat', angstrom=True),
-    Filter(['unfilt.', '0', 'Clear', 'C', 'clear'], 'w', 0, 'Itagaki', filename='KAF-1001E.asci', linecolor='k'),
-    Filter('white', 'w', 0, 'MOSFiT', filename='white.txt', linecolor='k'),
-    Filter(['pseudobolometric', 'griz'], 'w', 0, 'MOSFiT', filename='pseudobolometric.txt', linecolor='k'),
+    Filter('Itagaki', 'w', 0, 'Itagaki', filename='KAF-1001E.asci', linecolor='k', italics=False),
+    Filter('white', 'w', 0, 'MOSFiT', filename='white.txt', linecolor='k', italics=False),
+    Filter(['unfilt.', '0', 'Clear', 'C', 'clear', 'pseudobolometric', 'griz'], 'w', 0, 'MOSFiT',
+           filename='pseudobolometric.txt', linecolor='k', italics=False),
     Filter('G', 'w', 0, 'Gaia', filename='GAIA_GAIA0.G.dat', angstrom=True, linecolor='k'),
-    Filter('Kepler', 'r', 0, 'Kepler', filename='Kepler_Kepler.K.dat', angstrom=True),
-    Filter('TESS', 'r', 0, 'TESS', filename='TESS_TESS.Red.dat', angstrom=True),
-    Filter('w', 'w', 0, 'Gunn', filename='pstr-wx-183.asci', linecolor='k'),
+    Filter('Kepler', 'r', 0, 'Kepler', filename='Kepler_Kepler.K.dat', angstrom=True, italics=False),
+    Filter('TESS', 'r', 0, 'TESS', filename='TESS_TESS.Red.dat', angstrom=True, italics=False),
+    Filter('DLT40', 'w', 0, 'DLT40', filename='QE_E2V_MBBBUV_Broadband.csv', linecolor='k', italics=False),
+    Filter('w', 'w', 0, 'Gunn', filename='PAN-STARRS_PS1.w.dat', angstrom=True, linecolor='k'),
     Filter(['o', 'orange'], 'orange', 0, 'ATLAS', filename='ATLAS_orange.txt'),
-    Filter(['r', "r'", 'rp', 'F625W'], '#FF7D00', 0, 'Gunn', filename='sdss-rp-183.asci'),
+    Filter(['r', "r'", 'rp', 'F625W'], '#FF7D00', 0, 'Gunn', filename='SLOAN_SDSS.r.dat', angstrom=True),
     Filter('r-DECam', '#FF7D00', 0, 'DECam', filename='CTIO_DECam.r.dat', angstrom=True),
-    Filter(['R', 'Rc', 'R_s'], '#FF7000', 0, 'Johnson', 3.064e-23, filename='cous-rs-183.asci'),  # '#CC5900'
-    Filter(['i', "i'", 'ip', 'F775W'], '#90002C', -1, 'Gunn', filename='sdss-ip-183.asci'),
+    Filter(['R', 'Rc', 'R_s'], '#FF7000', 0, 'Johnson', 3.064e-23, filename='Generic_Cousins.R.dat', angstrom=True),  # '#CC5900'
+    Filter(['i', "i'", 'ip', 'F775W'], '#90002C', -1, 'Gunn', filename='SLOAN_SDSS.i.dat', angstrom=True),
     Filter('i-DECam', '#90002C', -1, 'DECam', filename='CTIO_DECam.i.dat', angstrom=True),
-    Filter(['I', 'Ic'], '#66000B', -1, 'Johnson', 2.416e-23, filename='cous-ic-183.asci'),  # brightened from '#1C0003'
-    Filter(['z', "z'", 'Z', 'zs'], '#000000', -2, 'Gunn', filename='pstr-zs-183.asci'),
+    Filter(['I', 'Ic'], '#66000B', -1, 'Johnson', 2.416e-23, filename='Generic_Cousins.I.dat', angstrom=True),  # brightened from '#1C0003'
+    Filter('zs', '#000000', -2, 'Gunn', filename='PAN-STARRS_PS1.z.dat', angstrom=True),
+    Filter(['z', "z'", 'zp'], '#000000', -2, 'Gunn', filename='SLOAN_SDSS.z.dat', angstrom=True),
     Filter('z-DECam', '#000000', -2, 'DECam', filename='CTIO_DECam.z.dat', angstrom=True),
-    Filter('y', 'y', -3, 'Gunn', filename='pstr-yx-183.asci'),
+    Filter('y', 'y', -3, 'Gunn', filename='PAN-STARRS_PS1.y.dat', angstrom=True),
     Filter('y-DECam', 'y', -3, 'DECam', filename='CTIO_DECam.Y.dat', angstrom=True),
     Filter('J', '#444444', -2, 'UKIRT', 1.589e-23, filename='Gemini_Flamingos2.J.dat', angstrom=True),
     Filter('H', '#888888', -3, 'UKIRT', 1.021e-23, filename='Gemini_Flamingos2.H.dat', angstrom=True),
     Filter(['K', 'Ks'], '#CCCCCC', -4, 'UKIRT', 0.640e-23, filename='Gemini_Flamingos2.Ks.dat', angstrom=True),
     Filter('L', 'r', -4, 'UKIRT', 0.285e-23),
-    Filter(['unknown', '?'], 'w', 0, 'unknown', linecolor='k')]
+    Filter(['unknown', '?'], 'w', 0, 'unknown', linecolor='k', italics=False)]
 Filter.order = [f.name for f in all_filters]
 filtdict = {}
 for filt in all_filters:
