@@ -158,22 +158,28 @@ def shock_cooling(t_in, f, v_s, M_env, f_rho_M, R, t_exp=0., kappa=1., n=1.5, RW
     return y_fit
 
 
-def t_min(v_s, M_env, f_rho_M, R, t_exp=0., kappa=1.):
+def t_min(p, kappa=1.):
     """
     The minimum validity time for the :func:`shock_cooling` model
 
     :math:`t_\\mathrm{min} = (0.2\\,\\mathrm{d}) \\frac{R}{v_s}
     \\max\\left[0.5, \\frac{R^{0.4}}{(f_ρ M κ)^{0.2} v_s^{-0.7}}\\right] + t_\\mathrm{exp}` (Eq. 17)
     """
+    v_s = p[0]
+    f_rho_M = p[2]
+    R = p[3]
+    t_exp = p[4] if len(p) > 4 else 0.
     return 0.2 * R / v_s * np.maximum(0.5, R ** 0.4 * (f_rho_M * kappa) ** -0.2 * v_s ** -0.7) + t_exp
 
 
-def t_max(v_s, M_env, f_rho_M, R, t_exp=0., kappa=1.):
+def t_max(p, kappa=1.):
     """
     The maximum validity time for the :func:`shock_cooling` model
 
     :math:`t_\\mathrm{max} = (7.4\,\\mathrm{d}) \\left(\\frac{R}{κ}\\right)^{0.55} + t_\\mathrm{exp}` (Eq. 24)
     """
+    R = p[3]
+    t_exp = p[4] if len(p) > 4 else 0.
     return 7.4 * (R / kappa) ** 0.55 + t_exp
 
 
@@ -273,12 +279,15 @@ def t_min2(*args):
     raise NotImplementedError('t_min cannot be translated to these parameters')
 
 
-def t_max2(T_1, L_1=0., t_tr=0., t_exp=0., n=1.5):
+def t_max2(p, n=1.5):
     """
     The maximum validity time for the :func:`shock_cooling2` model
 
     :math:`t_\\mathrm{max} = \\left(\\frac{8.12\\,\\mathrm{kK}}{T_1}\\right)^{1/(2 ε_1 - 0.5)} + t_\\mathrm{exp}`
     """
+    T_1 = p[0]
+    t_exp = p[3] if len(p) > 3 else 0.
+
     if n == 1.5:
         epsilon_1 = 0.027
     elif n == 3.:
